#!/bin/bash

# Explicitly set the PATH variable for the script to find system binaries
export PATH="/usr/sbin:/usr/bin:/sbin:/bin"

# Log the event for debugging
echo "$(date) - Starting mount process" >> /tmp/usb-mount.log

# Find the latest /dev/sdX device (based on the latest block device)
LATEST_DEVICE=$(ls -1 /dev/sd* | sort | tail -n 1)

if [ -z "$LATEST_DEVICE" ]; then
    echo "No valid devices found" >> /tmp/usb-mount.log
    exit 1
else 
    echo "Latest device: $LATEST_DEVICE" >> /tmp/usb-mount.log
fi

# Check if the device is a USB drive by inspecting udev properties.
# This ensures we ignore non-USB devices such as eth-to-USB converters.
if ! udevadm info --query=property --name="$LATEST_DEVICE" | grep -q "ID_BUS=usb"; then
    echo "Device $LATEST_DEVICE is not a USB drive" >> /tmp/usb-mount.log
    exit 1
fi

# Get the partition name (e.g., sda1, sdb1)
DEVICE_NAME=$(basename "$LATEST_DEVICE")

echo "DEVICE NAME: $DEVICE_NAME" >> /tmp/usb-mount.log

# Create the mount point
MOUNTPOINT="/media/usb"
mkdir -p "$MOUNTPOINT"

# Mount the device
mount "$LATEST_DEVICE" "$MOUNTPOINT" 2>> /tmp/usb-mount.log

if [ $? -eq 0 ]; then
    echo "Mounted $LATEST_DEVICE at $MOUNTPOINT" >> /tmp/usb-mount.log
else
    echo "Failed to mount $LATEST_DEVICE" >> /tmp/usb-mount.log
    exit 1
fi

# Search for key, copy to /data/modalai/vtx.key
KEY_FILE=$(find "$MOUNTPOINT" -type f -name "vtx.key" | head -n 1)

if [ -z "$KEY_FILE" ]; then
    echo "Key file not found" >> /tmp/usb-mount.log
    exit 1
else
    echo "Found key file: $KEY_FILE" >> /tmp/usb-mount.log
fi

# Copy the key file to disk
mkdir -p /data/modalai
cp "$KEY_FILE" /data/modalai/

if [ $? -eq 0 ]; then
    echo "Key file copied successfully to /data/modalai/" >> /tmp/usb-mount.log
else
    echo "Failed to copy key file" >> /tmp/usb-mount.log
    exit 1
fi
