#!/bin/bash

export PATH="/usr/sbin:/usr/bin:/sbin:/bin"

echo "$(date) - Running in environment: $(env)" >> /tmp/usb-umount.log
echo "$(date) - Starting unmount process" >> /tmp/usb-umount.log

MOUNTPOINT="/media/usb"
TIMEOUT=30  # Maximum time to wait for processes to close (in seconds)

# Check if the mount point is actually mounted
if mountpoint -q "$MOUNTPOINT"; then
    echo "$(date) - $MOUNTPOINT is mounted, attempting to unmount" >> /tmp/usb-umount.log
    
    SECONDS=0
    while ! umount "$MOUNTPOINT" >> /tmp/usb-umount.log 2>&1; do
        echo "$(date) - $MOUNTPOINT is busy, waiting..." >> /tmp/usb-umount.log

        # Check if we have waited too long
        if (( SECONDS >= TIMEOUT )); then
            echo "$(date) - Timeout reached, failed to unmount $MOUNTPOINT" >> /tmp/usb-umount.log
            exit 1
        fi

        # Wait for a short period before retrying
        sleep 1
    done

    echo "$(date) - Unmounted $MOUNTPOINT successfully" >> /tmp/usb-umount.log
    rmdir "$MOUNTPOINT"
else
    echo "$(date) - $MOUNTPOINT is not mounted" >> /tmp/usb-umount.log
fi
