import serial
import select
import sys

SERIAL_PORT = "/dev/ttyHS1"
BAUDRATE = 115200
BUFFER_SIZE = 18

try:
    ser = serial.Serial(
        SERIAL_PORT,
        BAUDRATE,
        timeout=1,  # Timeout in seconds for read
        bytesize=serial.EIGHTBITS,
        parity=serial.PARITY_NONE,
        stopbits=serial.STOPBITS_ONE,
        rtscts=False,
        dsrdtr=False
    )
except serial.SerialException as e:
    print(f"Error opening serial port: {e}")
    sys.exit(1)

print("Listening for UART data...")

try:
    while True:
        rlist, _, _ = select.select([ser], [], [], 1)  # 1-second timeout
        if ser in rlist:
            data = ser.read(BUFFER_SIZE)
            if data:
                print(f"Read {len(data)} bytes: {data.decode(errors='ignore')}")
        else:
            print("Timeout: No data received")
except KeyboardInterrupt:
    print("\nExiting...")
finally:
    ser.close()
